import test from 'ava'
import Helpers from '../test_helper.js'

var car, ticket, owner

test.beforeEach(t => {
    car = new Helpers.Car(1)
    ticket  = new Helpers.Ticket(2, car)
    owner = new Helpers.Owner(3, ticket)
})

test.after('cleanup', t => {
})

test('Class name property should equal cars', t => {
    t.is('cars', car.process_class_name(car.constructor.name))
})

test('Test constructing url', t => {
    const url_with_id = car.construct_url()
    t.is('cars/1', url_with_id)
})

test('Test sub-resources 2 levels down', t => {
    const url_with_id = ticket.construct_url(2, ticket.parent)
    t.is('cars/1/tickets/2', url_with_id)
})

test('Test sub-resources 3 levels down', t => {
    const url_with_id = owner.construct_url(3, owner.parent)
    t.is('cars/1/tickets/2/owners/3', url_with_id)
})

test('Test encoding query data', t => {
	const data = {'testKey':'one'}
	const query_str = car.encodeQueryData(data)
	t.is('?testKey=one&', query_str)
})

test('test constructing url with query params', t => {
	const data = {
		'testKey' :'one',
		'testKey2':'two'
	}
	car.id = 0
	const url = car.construct_url(0, {}, data)
	t.is('cars/?testKey=one&testKey2=two&',url)
})

test('test adding subresources', t => {
	ticket.sub_resources = ['search']
	const url = ticket.construct_url(2, ticket.parent)

	t.is('cars/1/tickets/2/search', url)
})

test('test merging options', t => {
    let default_request = {
        method: '',
        uri: '',
        body: {},
        json: true
    }
    let custom_request = { auth: {'user': 'this', 'pass': 'that'} }
    let merged = car.merge_options(default_request, custom_request)
    t.is(merged['auth']['user'],'this')
})
